// /common/http.interceptor.js
import baseUrl from './baseUrl.js';
// 这里的vm，就是我们在vue文件里面的this，所以我们能在这里获取vuex的变量，比如存放在里面的token变量
const install = (Vue, vm) => {
	// 此为自定义配置参数，具体参数见上方说明
	Vue.prototype.$u.http.setConfig({
		baseUrl:baseUrl,
		dataType: 'json',
		showLoading: true, // 是否显示请求中的loading
		loadingText: '请求中...', // 请求loading中的文字提示
		loadingTime: 800, // 在此时间内，请求还没回来的话，就显示加载中动画，单位ms
		originalData: true, // 是否在拦截器中返回服务端的原始数据
		loadingMask: true, // 展示loading的时候，是否给一个透明的蒙层，防止触摸穿透
		// 设置自定义头部content-type
		header: {
			'content-type': 'application/json',
		}
		// ......
	});

	// 请求拦截，配置Token等参数
	Vue.prototype.$u.http.interceptor.request = (config) => {
		// 引用token
		// 方式一，存放在vuex的token，假设使用了uView封装的vuex方式
		// 见：https://uviewui.com/components/globalVariable.html
		// config.header.token = vm.token;

		// 方式二，如果没有使用uView封装的vuex方法，那么需要使用$store.state获取
		// config.header.token = vm.$store.state.token;

		// 方式三，如果token放在了globalData，通过getApp().globalData获取
		// config.header.token = getApp().globalData.username;

		// 方式四，如果token放在了Storage本地存储中，拦截是每次请求都执行的
		// 所以哪怕您重新登录修改了Storage，下一次的请求将会是最新值
		const token = uni.getStorageSync('token');
		config.header['Authorization'] = token ?'Bearer '+token : '';
		// 可以对某个url进行特别处理，此url参数为this.$u.get(url)中的url值
		// if (config.url == '/user/login') config.header.noToken = true;
		if(config.method=='GET' || config.method=='PUT' || config.method=='DELETE'){
			if(config.data){
				config.url = config.url+config.data;
			}
		}
		// 最后需要将config进行return
		return config;
		// 如果return一个false值，则会取消本次请求
		// if(config.url == '/user/rest') return false; // 取消某次请求
	}

	// 响应拦截，判断状态码是否通过
	Vue.prototype.$u.http.interceptor.response = (res) => {
		// console.log(res); 
		if (res.statusCode == 200) {
			// res为服务端返回值，可能有code，result等字段
			// 这里对res.result进行返回，将会在this.$u.post(url).then(res => {})的then回调中的res的到
			// 如果配置了originalData为true，请留意这里的返回值
			return res;
		} else if (res.statusCode == 401) {
			uni.showToast({
				title: '您的身份信息已过期,请重新登录',
				icon: 'none',
				mask: true,
				duration: 2000,
				success: function() {
					uni.setStorageSync('token', null);
					uni.setStorageSync('userInfo', null);
					setTimeout(function() {
						// const pages = getCurrentPages();
						// if (pages.length>0 && pages[0].route != "pages/login/login") {
							uni.navigateTo({
								url: '/pages/login/login',
							})
						// }
					}, 2000)
				}
			})
		}else if(res.statusCode>=500 && res.statusCode!=502){
			uni.showToast({
				title:"服务器异常",
				icon:'none',
				duration:2000,
			})
			return false;
		}else if(res.statusCode==502) {
			uni.showToast({
				title:"服务不可用",
				icon:'none',
				duration:2000,
			})
			// uni.showToast({
			// 	icon:"none",
			//     title: res.message,
			//     duration: 2000
			// });
			// uni.$u.toast(res.message);
			// vm.$u.toast(res.message);
			// 如果返回false，则会调用Promise的reject回调，
			// 并将进入this.$u.post(url).then().catch(res=>{})的catch回调中，res为服务端的返回值
			return false;
		}else{
			uni.showToast({
				title:res.data.detail,
				icon:'none',
				duration:2000,
			})
			return false;
		}
	}
}

export default {
	install
}
